﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.WindowsAPICodePack.Sensors;

namespace DemoApp
{
	/// <summary>
	/// Interaction logic for Window1.xaml
	/// </summary>
	public partial class Window1 : Window
	{
		public Window1()
		{
			InitializeComponent();
		}

		private void Window_Loaded(object sender, RoutedEventArgs e)
		{
			SensorManager.SensorsChanged += SensorManagerSensorsChanged;
			UpdateSensorsList();
		}

		void SensorManagerSensorsChanged(SensorsChangedEventArgs change)
		{
			Dispatcher.Invoke((System.Threading.ThreadStart)(UpdateSensorsList));
		}

		private void UpdateSensorsList()
		{
			var sensors = SensorManager.GetSensorsByTypeId<AmbientLightSensor>();
			foreach (var sensor in sensors)

				sensor.DataReportChanged += delegate(Sensor sender, EventArgs e)
												{
													Dispatcher.Invoke((System.Threading.ThreadStart)(delegate
																										{
																											if (ActiveSensorsListBox.SelectedItem == sender)
																											{
																												CurrentValue.Text =
																													((AmbientLightSensor)sender).CurrentLuminousIntensity.Intensity.ToString();
																											}

																										}));
												};

			ActiveSensorsListBox.ItemsSource = sensors.ToArray();
			ActiveSensorsListBox.SelectedIndex = 0;
		}
	}

	class AmbientCorrectionConverter : DependencyObject, IValueConverter
	{
		public double Sensitivity
		{
			get; set;
		}

		#region IValueConverter Members

		public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
		{
			double currentValue = 0;

			if (value is double)
			{
				currentValue = (double)value;
			}
			else
			{
				double.TryParse(value.ToString(), out currentValue);
			}

			return currentValue / Sensitivity;
		}

		public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
		{
			throw new NotSupportedException();
		}

		#endregion
	}

}